@@ -16,10 +16,20 @@ class OsSlim():
             for pkg in cache:
                 if pkg.is_auto_removable and not pkg.name.startswith('linux'):
                 #if pkg.is_installed and pkg.name.startswith('linux-headers'):
-                    tmp_packages_list = [pkg.name, pkg.summary, common.confirm_filesize_unit(pkg.installedSize)]
+                    tmp_packages_list = [pkg.name, pkg.installed.summary, common.confirm_filesize_unit(pkg.installed.installed_size)]
                     spare_packages_list.append('<2_2>'.join(tmp_packages_list))
         return spare_packages_list
 
+    def scan_spare_packages(self):
+        cache = common.get_cache_list()
+        final_spare_list = []
+        if cache:
+            for pkg in cache:
+                if pkg.is_auto_removable and not pkg.name.startswith('linux'):
+                    final_spare_list.append(pkg)
+        return final_spare_list
+
+
 if __name__ == '__main__':
     obj = OsSlim()
     obj.get_spare_packages()
