@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013 National University of Defense Technology(NUDT) & Kylin Ltd.
+ * Copyright (C) 2013 ~ 2014 National University of Defense Technology(NUDT) & Kylin Ltd.
  *
  * Authors:
  *  lenky gao    lenky0401@gmail.com
@@ -74,7 +74,7 @@ FcitxCfgWizard::~FcitxCfgWizard()
     delete m_connection;
     if (m_improxy)
         delete m_improxy;
-    delete fcitxWarnSig;
+//    delete fcitxWarnSig;
 }
 
 bool FcitxCfgWizard::connected()
@@ -599,7 +599,6 @@ int FcitxCfgWizard::get_im_switch_hot_key()
 void FcitxCfgWizard::set_im_switch_hot_key(int hotkey, bool real_save)
 {
     m_im_switch_hot_key = hotkey;
-
     if (real_save) {
         set_fcitx_cfg_value("configdesc", "config.desc", "", "config", "Hotkey",
             "IMSwitchHotkey", &m_im_switch_hot_key);
@@ -682,8 +681,7 @@ QStringList FcitxCfgWizard::get_all_skin_type()
     QFileInfoList list;
     QFileInfoList::Iterator list_iter;
     char **skin_path = FcitxXDGGetPathWithPrefix(&len, "skin");
-
-    for (i = 0; i < len; i ++) {
+    for (i = 0; i < len; i++) {
         skin_dir = QDir(skin_path[i]);
         if (!skin_dir.exists())
             continue;
@@ -714,12 +712,12 @@ void FcitxCfgWizard::all_cfg_save()
     set_candidate_word_number(m_candidate_word_number, true);
     set_font_size(m_font_size, true);
     set_vertical_list(m_vertical_list, true);
-    set_trigger_key();
-    set_prev_page_key();
-    set_next_page_key();
     set_im_switch_hot_key(m_im_switch_hot_key, true);
     set_im_switch_key(m_im_switch_key, true);
     set_skin_type(m_skin_type, true);
+    set_trigger_key();
+    set_prev_page_key();
+    set_next_page_key();
     update_cfg_to_fcitx();
 }
 
@@ -790,7 +788,7 @@ void FcitxCfgWizard::send_fcitx_ok_warn(int window_x, int window_y)
 
 void FcitxCfgWizard::create_fcitx_ok_warn(int window_x, int window_y)
 {
-      fcitxWarnSig = new FcitxWarnDialog();
+      FcitxWarnDialog *fcitxWarnSig = new FcitxWarnDialog();
       connect(fcitxWarnSig,SIGNAL(fcitxWarntest()),this,SLOT(emitrefreshFcitxSig()));
       this->alert_x = window_x + (mainwindow_width / 2) - (alert_width  / 2);
       this->alert_y = window_y + mainwindow_height - 400;
