@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013 National University of Defense Technology(NUDT) & Kylin Ltd.
+ * Copyright (C) 2013 ~ 2014 National University of Defense Technology(NUDT) & Kylin Ltd.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,21 +17,22 @@
 #ifndef SYSTEMAPPLICATION_H
 #define SYSTEMAPPLICATION_H
 #include <QDeclarativeView>
-#include <QApplication>
-#include <QMouseEvent>
-#include "QPoint"
 #include "tray.h"
 #include "alertdialog.h"
 #include <QDBusInterface>
 #include <QDBusConnection>
 #include <QtGui>
-class IhuApplication : public QApplication
+
+//#include <QPixmap>
+class IhuApplication : public QWidget
 {
     Q_OBJECT
 public:
-    IhuApplication(int &argc, char **argv);
+    explicit IhuApplication(QWidget *parent = 0);
     virtual ~IhuApplication();
-    bool setup();
+    void setup();
+    void showQMLWidget();
+
 private:
     //关联QML界面
     QDeclarativeView *viewer;
@@ -41,4 +42,5 @@ public slots:
     //主界面显示和隐藏
     void showOrHideMainPage();
 };
+
 #endif // SYSTEMAPPLICATION_H
